Force Fields

# 4 Force Fields

`NanoCap` implements force fields for the optimisation of the both the dual lattices and carbon lattices of each structure. When a structure is saved information relating to the force field is also stored. This allows the same topologies to be optimised by various force fields. Outlined in the next sections are the force fields currently available in `NanoCap` .

- 4.1 Dual Lattice Force Fields
- 4.2 Carbon Lattice Force Fields